@@ -6,19 +6,16 @@
 # Created DEJH, March 2014.
 from __future__ import print_function
 
+import numpy as np
 from six import string_types
 
-import numpy as np
-from landlab import Component
-
+from landlab import BAD_INDEX_VALUE as UNDEFINED_INDEX, Component, RasterModelGrid
 from landlab.utils.decorators import use_file_name_or_kwds
 
-from landlab import BAD_INDEX_VALUE as UNDEFINED_INDEX
-
-from landlab import RasterModelGrid
-
-from .cfuncs import (brent_method_erode_fixed_threshold,
-                     brent_method_erode_variable_threshold)
+from .cfuncs import (
+    brent_method_erode_fixed_threshold,
+    brent_method_erode_variable_threshold,
+)
 
 
 class FastscapeEroder(Component):
@@ -54,12 +51,12 @@ class FastscapeEroder(Component):
     if :math:`K A^m S^n <= \textit{threshold_sp}`.
 
     This module assumes you have already run
-    :func:`landlab.components.flow_routing.route_flow_dn.FlowRouter.route_flow`
+    :func:`landlab.components.flow_accum.flow_accumulator.FlowAccumulator.run_one_step`
     in the same timestep. It looks for 'flow__upstream_node_order',
     'flow__link_to_receiver_node', 'drainage_area', 'flow__receiver_node', and
     'topographic__elevation' at the nodes in the grid. 'drainage_area' should
     be in area upstream, not volume (i.e., set runoff_rate=1.0 when calling
-    FlowRouter.route_flow).
+    FlowAccumulator.run_one_step).
 
     The primary method of this class is :func:`run_one_step`.
 
@@ -68,16 +65,16 @@ class FastscapeEroder(Component):
     >>> import numpy as np
     >>> from landlab import RasterModelGrid
     >>> from landlab import CLOSED_BOUNDARY, FIXED_VALUE_BOUNDARY
-    >>> from landlab.components import FlowRouter, FastscapeEroder
+    >>> from landlab.components import FlowAccumulator, FastscapeEroder
 
-    >>> grid = RasterModelGrid((5, 5), spacing=10.)
+    >>> grid = RasterModelGrid((5, 5), xy_spacing=10.)
     >>> z = np.array([7.,  7.,  7.,  7.,  7.,
     ...               7.,  5., 3.2,  6.,  7.,
     ...               7.,  2.,  3.,  5.,  7.,
     ...               7.,  1., 1.9,  4.,  7.,
     ...               7.,  0.,  7.,  7.,  7.])
     >>> z = grid.add_field('topographic__elevation', z, at='node')
-    >>> fr = FlowRouter(grid)
+    >>> fr = FlowAccumulator(grid, flow_director='D8')
     >>> sp = FastscapeEroder(grid, K_sp=1.)
     >>> fr.run_one_step()
     >>> sp.run_one_step(dt=1.)
@@ -88,14 +85,14 @@ class FastscapeEroder(Component):
             7.        ,  0.28989795,  0.85403051,  2.42701526,  7.        ,
             7.        ,  0.        ,  7.        ,  7.        ,  7.        ])
 
-    >>> grid = RasterModelGrid((3, 7), spacing=1.)
+    >>> grid = RasterModelGrid((3, 7), xy_spacing=1.)
     >>> z = np.array(grid.node_x ** 2.)
     >>> z = grid.add_field('topographic__elevation', z, at='node')
     >>> grid.status_at_node[grid.nodes_at_left_edge] = FIXED_VALUE_BOUNDARY
     >>> grid.status_at_node[grid.nodes_at_top_edge] = CLOSED_BOUNDARY
     >>> grid.status_at_node[grid.nodes_at_bottom_edge] = CLOSED_BOUNDARY
     >>> grid.status_at_node[grid.nodes_at_right_edge] = CLOSED_BOUNDARY
-    >>> fr = FlowRouter(grid)
+    >>> fr = FlowAccumulator(grid, flow_director='D8')
     >>> sp = FastscapeEroder(grid, K_sp=0.1, m_sp=0., n_sp=2.,
     ...                      threshold_sp=2.)
     >>> fr.run_one_step()
@@ -104,14 +101,14 @@ class FastscapeEroder(Component):
     array([  0.        ,   1.        ,   4.        ,   8.52493781,
             13.29039716,  18.44367965,  36.        ])
 
-    >>> grid = RasterModelGrid((3, 7), spacing=1.)
+    >>> grid = RasterModelGrid((3, 7), xy_spacing=1.)
     >>> z = np.array(grid.node_x ** 2.)
     >>> z = grid.add_field('topographic__elevation', z, at='node')
     >>> grid.status_at_node[grid.nodes_at_left_edge] = FIXED_VALUE_BOUNDARY
     >>> grid.status_at_node[grid.nodes_at_top_edge] = CLOSED_BOUNDARY
     >>> grid.status_at_node[grid.nodes_at_bottom_edge] = CLOSED_BOUNDARY
     >>> grid.status_at_node[grid.nodes_at_right_edge] = CLOSED_BOUNDARY
-    >>> fr = FlowRouter(grid)
+    >>> fr = FlowAccumulator(grid, flow_director='D8')
     >>> K_field = grid.ones(at='node') # K can be a field
     >>> sp = FastscapeEroder(grid, K_sp=K_field, m_sp=1., n_sp=0.6,
     ...                      threshold_sp=grid.node_x,
@@ -127,55 +124,57 @@ class FastscapeEroder(Component):
     True
     """
 
-    _name = 'FastscapeEroder'
+    _name = "FastscapeEroder"
 
     _input_var_names = (
-        'topographic__elevation',
-        'drainage_area',
-        'flow__link_to_receiver_node',
-        'flow__upstream_node_order',
-        'flow__receiver_node',
+        "topographic__elevation",
+        "drainage_area",
+        "flow__link_to_receiver_node",
+        "flow__upstream_node_order",
+        "flow__receiver_node",
     )
 
-    _output_var_names = (
-        'topographic__elevation',
-    )
+    _output_var_names = ("topographic__elevation",)
 
     _var_units = {
-        'topographic__elevation': 'm',
-        'drainage_area': 'm**2',
-        'flow__link_to_receiver_node': '-',
-        'flow__upstream_node_order': '-',
-        'flow__receiver_node': '-',
+        "topographic__elevation": "m",
+        "drainage_area": "m**2",
+        "flow__link_to_receiver_node": "-",
+        "flow__upstream_node_order": "-",
+        "flow__receiver_node": "-",
     }
 
     _var_mapping = {
-        'topographic__elevation': 'node',
-        'drainage_area': 'node',
-        'flow__link_to_receiver_node': 'node',
-        'flow__upstream_node_order': 'node',
-        'flow__receiver_node': 'node',
+        "topographic__elevation": "node",
+        "drainage_area": "node",
+        "flow__link_to_receiver_node": "node",
+        "flow__upstream_node_order": "node",
+        "flow__receiver_node": "node",
     }
 
     _var_doc = {
-        'topographic__elevation': 'Land surface topographic elevation',
-        'drainage_area':
-            "Upstream accumulated surface area contributing to the node's "
-            "discharge",
-        'flow__link_to_receiver_node':
-            'ID of link downstream of each node, which carries the discharge',
-        'flow__upstream_node_order':
-            'Node array containing downstream-to-upstream ordered list of '
-            'node IDs',
-        'flow__receiver_node':
-            'Node array of receivers (node that receives flow from current '
-            'node)',
+        "topographic__elevation": "Land surface topographic elevation",
+        "drainage_area": "Upstream accumulated surface area contributing to the node's "
+        "discharge",
+        "flow__link_to_receiver_node": "ID of link downstream of each node, which carries the discharge",
+        "flow__upstream_node_order": "Node array containing downstream-to-upstream ordered list of "
+        "node IDs",
+        "flow__receiver_node": "Node array of receivers (node that receives flow from current "
+        "node)",
     }
 
     @use_file_name_or_kwds
-    def __init__(self, grid, K_sp=None, m_sp=0.5, n_sp=1., threshold_sp=0.,
-                 rainfall_intensity=1., discharge_name='drainage_area',
-                 **kwds):
+    def __init__(
+        self,
+        grid,
+        K_sp=None,
+        m_sp=0.5,
+        n_sp=1.0,
+        threshold_sp=0.0,
+        rainfall_intensity=1.0,
+        discharge_name="drainage_area",
+        **kwds
+    ):
         """
         Initialize the Fastscape stream power component. Note: a timestep,
         dt, can no longer be supplied to this component through the input file.
@@ -201,13 +200,15 @@ class FastscapeEroder(Component):
             different field, such as 'surface_water__discharge', give its name in
             this argument.
         """
-        if 'flow__receiver_node' in grid.at_node:
-            if (grid.at_node['flow__receiver_node'].size != grid.size('node')):
-                msg = ('A route-to-multiple flow director has been '
-                       'run on this grid. The landlab development team has not '
-                       'verified that FastscapeEroder is compatible with '
-                       'route-to-multiple methods. Please open a GitHub Issue '
-                       'to start this process.')
+        if "flow__receiver_node" in grid.at_node:
+            if grid.at_node["flow__receiver_node"].size != grid.size("node"):
+                msg = (
+                    "A route-to-multiple flow director has been "
+                    "run on this grid. The landlab development team has not "
+                    "verified that FastscapeEroder is compatible with "
+                    "route-to-multiple methods. Please open a GitHub Issue "
+                    "to start this process."
+                )
                 raise NotImplementedError(msg)
 
         self._grid = grid
@@ -225,17 +226,19 @@ class FastscapeEroder(Component):
             assert self.thresholds.size == self.grid.number_of_nodes
 
         # make storage variables
-        self.A_to_the_m = grid.zeros(at='node')
-        self.alpha = grid.empty(at='node')
+        self.A_to_the_m = grid.zeros(at="node")
+        self.alpha = grid.empty(at="node")
 
         if self.K is None:
-            raise ValueError('K_sp must be set as a float, node array, or ' +
-                             'field name. It was None.')
+            raise ValueError(
+                "K_sp must be set as a float, node array, or "
+                + "field name. It was None."
+            )
 
         # now handle the inputs that could be float, array or field name:
         # some support here for old-style inputs
         if isinstance(K_sp, string_types):
-            if K_sp == 'array':
+            if K_sp == "array":
                 self.K = None
             else:
                 self.K = self._grid.at_node[K_sp]
@@ -244,41 +247,52 @@ class FastscapeEroder(Component):
         else:
             self.K = np.asarray(K_sp, dtype=float)
             if len(self.K) != self.grid.number_of_nodes:
-                raise TypeError('Supplied value of K_sp is not n_nodes long')
+                raise TypeError("Supplied value of K_sp is not n_nodes long")
 
         if isinstance(rainfall_intensity, string_types):
-            raise ValueError('This component can no longer handle ' +
-                             'spatially variable runoff directly. Use ' +
-                             'FlowAccumulator with specified ' +
-                             'water__unit_flux_in, or use StreamPowerEroder' +
-                             'component instead of FastscapeEroder.')
-            if rainfall_intensity == 'array':
+            raise ValueError(
+                "This component can no longer handle "
+                + "spatially variable runoff directly. Use "
+                + "FlowAccumulator with specified "
+                + "water__unit_flux_in, or use StreamPowerEroder"
+                + "component instead of FastscapeEroder."
+            )
+            if rainfall_intensity == "array":
                 self._r_i = None
             else:
                 self._r_i = self._grid.at_node[rainfall_intensity]
         elif isinstance(rainfall_intensity, (float, int)):  # a float
             self._r_i = float(rainfall_intensity)
         elif len(rainfall_intensity) == self.grid.number_of_nodes:
-            raise ValueError('This component can no longer handle '
-                             'spatially variable runoff directly. Use '
-                             'FlowAccumulator with specified '
-                             'water__unit_flux_in, or use StreamPowerEroder'
-                             'component instead of FastscapeEroder.')
+            raise ValueError(
+                "This component can no longer handle "
+                "spatially variable runoff directly. Use "
+                "FlowAccumulator with specified "
+                "water__unit_flux_in, or use StreamPowerEroder"
+                "component instead of FastscapeEroder."
+            )
             self._r_i = np.array(rainfall_intensity)
         else:
-            raise TypeError('Supplied type of rainfall_intensity was '
-                            'not recognised')
+            raise TypeError("Supplied type of rainfall_intensity was " "not recognised")
 
         # We now forbid changing of the field name
-        if 'value_field' in kwds.keys():
-            raise ValueError('This component can no longer support variable'
-                             'field names. Use "topographic__elevation".')
+        if "value_field" in kwds.keys():
+            raise ValueError(
+                "This component can no longer support variable"
+                'field names. Use "topographic__elevation".'
+            )
 
         # Handle option for area vs discharge
         self.discharge_name = discharge_name
 
-    def erode(self, grid_in, dt=None, K_if_used=None, flooded_nodes=None,
-              rainfall_intensity_if_used=None):
+    def erode(
+        self,
+        grid_in,
+        dt=None,
+        K_if_used=None,
+        flooded_nodes=None,
+        rainfall_intensity_if_used=None,
+    ):
         """Erode using stream power erosion.
 
         This method implements the stream power erosion, following the Braun-
@@ -322,43 +336,51 @@ class FastscapeEroder(Component):
         grid
             A reference to the grid.
         """
-        if (self._grid.at_node['flow__receiver_node'].size != self._grid.size('node')):
-            msg = ('A route-to-multiple flow director has been '
-                   'run on this grid. The landlab development team has not '
-                   'verified that FastscapeEroder is compatible with '
-                   'route-to-multiple methods. Please open a GitHub Issue '
-                   'to start this process.')
+        if self._grid.at_node["flow__receiver_node"].size != self._grid.size("node"):
+            msg = (
+                "A route-to-multiple flow director has been "
+                "run on this grid. The landlab development team has not "
+                "verified that FastscapeEroder is compatible with "
+                "route-to-multiple methods. Please open a GitHub Issue "
+                "to start this process."
+            )
             raise NotImplementedError(msg)
 
-        upstream_order_IDs = self._grid.at_node['flow__upstream_node_order']
-        z = self._grid.at_node['topographic__elevation']
+        upstream_order_IDs = self._grid.at_node["flow__upstream_node_order"]
+        z = self._grid.at_node["topographic__elevation"]
         defined_flow_receivers = np.not_equal(
-            self._grid.at_node['flow__link_to_receiver_node'], UNDEFINED_INDEX)
+            self._grid.at_node["flow__link_to_receiver_node"], UNDEFINED_INDEX
+        )
 
         if isinstance(self._grid, RasterModelGrid):
             flow_link_lengths = self._grid.length_of_d8[
-                self._grid.at_node['flow__link_to_receiver_node'][
-                    defined_flow_receivers]]
+                self._grid.at_node["flow__link_to_receiver_node"][
+                    defined_flow_receivers
+                ]
+            ]
         else:
             flow_link_lengths = self._grid.length_of_link[
-                self._grid.at_node['flow__link_to_receiver_node'][
-                    defined_flow_receivers]]
+                self._grid.at_node["flow__link_to_receiver_node"][
+                    defined_flow_receivers
+                ]
+            ]
         # make arrays from input the right size
         if isinstance(self.K, np.ndarray):
             K_here = self.K[defined_flow_receivers]
         else:
             K_here = self.K
         if rainfall_intensity_if_used is not None:
-            assert type(rainfall_intensity_if_used) in (float, np.float64,
-                                                        int)
+            assert type(rainfall_intensity_if_used) in (float, np.float64, int)
             r_i_here = float(rainfall_intensity_if_used)
         else:
             r_i_here = self._r_i
 
         if dt is None:
             dt = self.dt
-        assert dt is not None, ('Fastscape component could not find a dt to ' +
-                                'use. Pass dt to the run_one_step() method.')
+        assert dt is not None, (
+            "Fastscape component could not find a dt to "
+            + "use. Pass dt to the run_one_step() method."
+        )
 
         if self.K is None:  # "old style" setting of array
             assert K_if_used is not None
@@ -366,37 +388,43 @@ class FastscapeEroder(Component):
 
         n = float(self.n)
 
-        np.power(self._grid['node'][self.discharge_name], self.m,
-                 out=self.A_to_the_m)
+        np.power(self._grid["node"][self.discharge_name], self.m, out=self.A_to_the_m)
         self.alpha[defined_flow_receivers] = (
-            r_i_here**self.m * K_here * dt * self.A_to_the_m[
-                defined_flow_receivers] / (flow_link_lengths**self.n))
+            r_i_here ** self.m
+            * K_here
+            * dt
+            * self.A_to_the_m[defined_flow_receivers]
+            / (flow_link_lengths ** self.n)
+        )
 
-        flow_receivers = self._grid['node']['flow__receiver_node']
+        flow_receivers = self._grid["node"]["flow__receiver_node"]
         alpha = self.alpha
 
         # Handle flooded nodes, if any (no erosion there)
         if flooded_nodes is not None:
-            alpha[flooded_nodes] = 0.
+            alpha[flooded_nodes] = 0.0
         else:
             reversed_flow = z < z[flow_receivers]
             # this check necessary if flow has been routed across depressions
-            alpha[reversed_flow] = 0.
+            alpha[reversed_flow] = 0.0
 
         threshsdt = self.thresholds * dt
 
         # solve using Brent's Method in Cython for Speed
         if isinstance(self.thresholds, float):
             brent_method_erode_fixed_threshold(
-                upstream_order_IDs, flow_receivers, threshsdt, alpha, n, z)
+                upstream_order_IDs, flow_receivers, threshsdt, alpha, n, z
+            )
         else:
             brent_method_erode_variable_threshold(
-                upstream_order_IDs, flow_receivers, threshsdt, alpha, n, z)
+                upstream_order_IDs, flow_receivers, threshsdt, alpha, n, z
+            )
 
         return self._grid
 
-    def run_one_step(self, dt, flooded_nodes=None,
-                     rainfall_intensity_if_used=None, **kwds):
+    def run_one_step(
+        self, dt, flooded_nodes=None, rainfall_intensity_if_used=None, **kwds
+    ):
         """Erode for a single time step.
 
         This method implements the stream power erosion across one time
@@ -419,5 +447,9 @@ class FastscapeEroder(Component):
             Supply to drive this component with a time-varying spatially
             constant rainfall.
         """
-        self.erode(grid_in=self._grid, dt=dt, flooded_nodes=flooded_nodes,
-                   rainfall_intensity_if_used=rainfall_intensity_if_used)
+        self.erode(
+            grid_in=self._grid,
+            dt=dt,
+            flooded_nodes=flooded_nodes,
+            rainfall_intensity_if_used=rainfall_intensity_if_used,
+        )
