@@ -7,6 +7,8 @@ Do NOT add new documentation here. Grid documentation is now built in a semi-
 automated fashion. To modify the text seen on the web, edit the files
 `docs/text_for_[gridfile].py.txt`.
 """
+from __future__ import absolute_import
+
 from warnings import warn
 
 import numpy
@@ -15,7 +17,7 @@ import six
 from landlab.grid.voronoi import VoronoiDelaunayGrid
 
 from ..core.utils import as_id_array
-from .base import CLOSED_BOUNDARY, FIXED_VALUE_BOUNDARY, CORE_NODE
+from .base import CLOSED_BOUNDARY, CORE_NODE, FIXED_VALUE_BOUNDARY
 
 
 class HexModelGrid(VoronoiDelaunayGrid):
@@ -42,9 +44,11 @@ class HexModelGrid(VoronoiDelaunayGrid):
     orientation : string, optional
         One of the 3 cardinal directions in the grid, either 'horizontal'
         (default) or 'vertical'
-    shape : string, optional
+    node_layout : string, optional
         Controls the shape of the bounding hull, i.e., are the nodes arranged
         in a hexagon, or a rectangle? Either 'hex' (default) or 'rect'.
+    shape : tuple of 2 int
+        Alternative way to specify (base_num_rows, base_num_cols)
 
     Returns
     -------
@@ -57,7 +61,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
     have 2 nodes, and the second nodes.
 
     >>> from landlab import HexModelGrid
-    >>> hmg = HexModelGrid(3, 2, 1.0)
+    >>> hmg = HexModelGrid(shape=(3, 2), dx=1.0)
     >>> hmg.number_of_nodes
     7
     """
@@ -67,10 +71,11 @@ class HexModelGrid(VoronoiDelaunayGrid):
         base_num_rows=0,
         base_num_cols=0,
         dx=1.0,
-        xy_of_lower_left=(0., 0.),
+        xy_of_lower_left=(0.0, 0.0),
         orientation="horizontal",
-        shape="hex",
+        node_layout="hex",
         reorient_links=True,
+        shape=None,
         **kwds
     ):
         """Create a grid of hexagonal cells.
@@ -118,6 +123,14 @@ class HexModelGrid(VoronoiDelaunayGrid):
         >>> hmg.number_of_nodes
         7
         """
+
+        # Pre-LL2.0: handle shape and node_layout keyword args
+        # (note: in LL2.0, shape should refer ONLY to rows and columns)
+        if type(shape) is str:  # "old" (LL < 2.0) usage
+            node_layout = shape
+        elif type(shape) is tuple:
+            (base_num_rows, base_num_cols) = shape
+
         xy_of_lower_left = tuple(xy_of_lower_left)
         # Set number of nodes, and initialize if caller has given dimensions
         if base_num_rows * base_num_cols > 0:
@@ -127,8 +140,9 @@ class HexModelGrid(VoronoiDelaunayGrid):
                 dx,
                 xy_of_lower_left,
                 orientation,
-                shape,
+                node_layout,
                 reorient_links,
+                shape,
             )
         self._xy_of_lower_left = xy_of_lower_left
         super(HexModelGrid, self).__init__(**kwds)
@@ -153,8 +167,9 @@ class HexModelGrid(VoronoiDelaunayGrid):
         dx,
         xy_of_lower_left,
         orientation,
-        shape,
+        node_layout,
         reorient_links=True,
+        shape=None,
     ):
         r"""Set up a hexagonal grid.
 
@@ -235,24 +250,36 @@ class HexModelGrid(VoronoiDelaunayGrid):
                 + ")"
             )
 
+        # Pre-LL2.0: handle shape and node_layout keyword args
+        # (note: in LL2.0, shape should refer ONLY to rows and columns)
+        if type(shape) is str:  # "old" (LL < 2.0) usage
+            node_layout = shape
+            message = (
+                "Use node_layout to specify 'rect' or 'hex' layout "
+                + "(usage will be enforced in Landlab 2.0+)."
+            )
+            warn(message=message, category=DeprecationWarning)
+        elif type(shape) is tuple:
+            (base_num_rows, base_num_cols) = shape
+
         # Make sure the parameter *orientation* is correct
         assert (
             orientation[0].lower() == "h" or orientation[0].lower() == "v"
         ), 'orientation must be either "horizontal" (default) or "vertical"'
 
-        # Make sure the parameter *shape* is correct
+        # Make sure the parameter *node_layout* is correct
         assert (
-            shape[0].lower() == "h" or shape[0].lower() == "r"
-        ), 'shape must be either "hex" (default) or "rect"'
+            node_layout[0].lower() == "h" or node_layout[0].lower() == "r"
+        ), 'node_layout must be either "hex" (default) or "rect"'
 
         # Create a set of hexagonally arranged points. These will be our nodes.
-        if orientation[0].lower() == "h" and shape[0].lower() == "h":
+        if orientation[0].lower() == "h" and node_layout[0].lower() == "h":
             pts = HexModelGrid._hex_points_with_horizontal_hex(
                 base_num_rows, base_num_cols, dx, xy_of_lower_left
             )
             self.orientation = "horizontal"
             self._nrows = base_num_rows
-        elif orientation[0].lower() == "h" and shape[0].lower() == "r":
+        elif orientation[0].lower() == "h" and node_layout[0].lower() == "r":
             pts = HexModelGrid._hex_points_with_horizontal_rect(
                 base_num_rows, base_num_cols, dx, xy_of_lower_left
             )
@@ -263,7 +290,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
             self._nodes = numpy.arange((self._nrows * self._ncols), dtype=int).reshape(
                 self._shape
             )
-        elif orientation[0].lower() == "v" and shape[0].lower() == "h":
+        elif orientation[0].lower() == "v" and node_layout[0].lower() == "h":
             pts = HexModelGrid._hex_points_with_vertical_hex(
                 base_num_rows, base_num_cols, dx, xy_of_lower_left
             )
@@ -290,11 +317,11 @@ class HexModelGrid(VoronoiDelaunayGrid):
         # the nodes into a grid.
         super(HexModelGrid, self)._initialize(pts[:, 0], pts[:, 1], reorient_links)
 
-        # Handle special case of boundary nodes in rectangular grid shape.
+        # Handle special case of boundary nodes in rectangular node layout.
         # One pair of edges will have the nodes staggered. By default, only the
         # outer nodes will be assigned boundary status; we need the inner edge
         # nodes on these "ragged" edges also to be flagged as boundary nodes.
-        if shape[0].lower() == "r":
+        if node_layout[0].lower() == "r":
             self._set_boundary_stat_at_rect_grid_ragged_edges(orientation, dx)
 
         # Remember grid spacing
@@ -303,7 +330,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
     def _set_boundary_stat_at_rect_grid_ragged_edges(self, orientation, dx):
         """Assign boundary status to all edge nodes along the 'ragged' edges.
 
-        Handle special case of boundary nodes in rectangular grid shape.
+        Handle special case of boundary nodes in rectangular node layout.
         One pair of edges will have the nodes staggered. By default, only the
         outer nodes will be assigned boundary status; we need the inner edge
         nodes on these "ragged" edges also to be flagged as boundary nodes.
@@ -311,18 +338,18 @@ class HexModelGrid(VoronoiDelaunayGrid):
         Examples
         --------
         >>> from landlab import HexModelGrid
-        >>> hg = HexModelGrid(3, 3, shape='rect', dx=2.0)
+        >>> hg = HexModelGrid(3, 3, node_layout='rect', dx=2.0)
         >>> hg.status_at_node
         array([1, 1, 1, 1, 0, 1, 1, 1, 1], dtype=uint8)
-        >>> hg = HexModelGrid(3, 3, shape='rect', orientation='vert')
+        >>> hg = HexModelGrid(3, 3, node_layout='rect', orientation='vert')
         >>> hg.status_at_node
         array([1, 1, 1, 1, 1, 0, 1, 1, 1], dtype=uint8)
-        >>> hg = HexModelGrid(4, 4, shape='rect', orientation='vert')
+        >>> hg = HexModelGrid(4, 4, node_layout='rect', orientation='vert')
         >>> hg.status_at_node
         array([1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 0, 1, 1, 1, 1, 1], dtype=uint8)
         >>> hg.boundary_nodes
         array([ 0,  1,  2,  3,  4,  7,  8, 11, 12, 13, 14, 15])
-        >>> hg = HexModelGrid(3, 4, shape='rect')
+        >>> hg = HexModelGrid(3, 4, node_layout='rect')
         >>> hg.status_at_node
         array([1, 1, 1, 1, 1, 0, 0, 1, 1, 1, 1, 1], dtype=uint8)
         """
@@ -402,8 +429,8 @@ class HexModelGrid(VoronoiDelaunayGrid):
         >>> points[:3, 0]
         array([ 0.5,  1.5,  0. ])
         """
-        dxv = dxh * numpy.sqrt(3.) / 2.
-        half_dxh = dxh / 2.
+        dxv = dxh * numpy.sqrt(3.0) / 2.0
+        half_dxh = dxh / 2.0
 
         if numpy.mod(num_rows, 2) == 0:  # even number of rows
             npts = num_rows * base_num_cols + (num_rows * num_rows) // 4
@@ -470,8 +497,8 @@ class HexModelGrid(VoronoiDelaunayGrid):
         >>> points[:3, 0]
         array([ 0.,  1.,  2.])
         """
-        dxv = dxh * numpy.sqrt(3.) / 2.
-        half_dxh = dxh / 2.
+        dxv = dxh * numpy.sqrt(3.0) / 2.0
+        half_dxh = dxh / 2.0
 
         npts = num_rows * num_cols
         pts = numpy.zeros((npts, 2))
@@ -525,8 +552,8 @@ class HexModelGrid(VoronoiDelaunayGrid):
         >>> points[:3, 1]
         array([ 0.5,  1.5,  0. ])
         """
-        dxh = dxv * numpy.sqrt(3.) / 2.
-        half_dxv = dxv / 2.
+        dxh = dxv * numpy.sqrt(3.0) / 2.0
+        half_dxv = dxv / 2.0
 
         if numpy.mod(num_cols, 2) == 0:  # even number of columns
             npts = base_num_rows * num_cols + (num_cols * num_cols) // 4
@@ -593,8 +620,8 @@ class HexModelGrid(VoronoiDelaunayGrid):
         >>> points[:3, 1]
         array([ 0.,  1.,  2.])
         """
-        dxh = dxv * numpy.sqrt(3.) / 2.
-        half_dxv = dxv / 2.
+        dxh = dxv * numpy.sqrt(3.0) / 2.0
+        half_dxv = dxv / 2.0
 
         npts = num_rows * num_cols
         pts = numpy.zeros((npts, 2))
@@ -626,7 +653,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         Examples
         --------
         >>> from landlab import HexModelGrid
-        >>> grid = HexModelGrid(5, 5, shape='rect')
+        >>> grid = HexModelGrid(5, 5, node_layout='rect')
         >>> grid.number_of_node_columns
         5
 
@@ -649,7 +676,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         Examples
         --------
         >>> from landlab import HexModelGrid
-        >>> grid = HexModelGrid(5, 5, shape='rect')
+        >>> grid = HexModelGrid(5, 5, node_layout='rect')
         >>> grid.number_of_node_rows
         5
 
@@ -665,7 +692,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         --------
         >>> import numpy as np
         >>> from landlab import HexModelGrid
-        >>> grid = HexModelGrid(3, 4, shape='rect')
+        >>> grid = HexModelGrid(3, 4, node_layout='rect')
         >>> grid.nodes_at_left_edge
         array([0, 4, 8])
 
@@ -684,7 +711,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         --------
         >>> import numpy as np
         >>> from landlab import HexModelGrid
-        >>> grid = HexModelGrid(3, 4, shape='rect')
+        >>> grid = HexModelGrid(3, 4, node_layout='rect')
         >>> grid.nodes_at_right_edge
         array([ 3,  7, 11])
 
@@ -703,7 +730,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         --------
         >>> import numpy as np
         >>> from landlab import HexModelGrid
-        >>> grid = HexModelGrid(3, 4, shape='rect')
+        >>> grid = HexModelGrid(3, 4, node_layout='rect')
         >>> grid.nodes_at_top_edge
         array([ 8,  9, 10, 11])
 
@@ -722,7 +749,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         --------
         >>> import numpy as np
         >>> from landlab import HexModelGrid
-        >>> grid = HexModelGrid(3, 4, shape='rect')
+        >>> grid = HexModelGrid(3, 4, node_layout='rect')
         >>> grid.nodes_at_bottom_edge
         array([0, 1, 2, 3])
 
@@ -739,10 +766,10 @@ class HexModelGrid(VoronoiDelaunayGrid):
         Examples
         --------
         >>> from landlab import HexModelGrid
-        >>> grid = HexModelGrid(3, 4, shape='rect', orientation='vert')
+        >>> grid = HexModelGrid(3, 4, node_layout='rect', orientation='vert')
         >>> grid.node_row_and_column(5)
         (1, 2)
-        >>> grid = HexModelGrid(3, 5, shape='rect', orientation='vert')
+        >>> grid = HexModelGrid(3, 5, node_layout='rect', orientation='vert')
         >>> grid.node_row_and_column(13)
         (2, 1)
         """
@@ -804,7 +831,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
 
         # Figure out whether the orientation is horizontal or vertical
         if self.orientation[0] == "h":  # horizontal
-            offsets[:, 0] = array([0., apothem, apothem, 0., -apothem, -apothem])
+            offsets[:, 0] = array([0.0, apothem, apothem, 0.0, -apothem, -apothem])
             offsets[:, 1] = array(
                 [
                     radius,
@@ -826,7 +853,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
                     -radius / 2.0,
                 ]
             )
-            offsets[:, 1] = array([apothem, 0., -apothem, -apothem, 0., apothem])
+            offsets[:, 1] = array([apothem, 0.0, -apothem, -apothem, 0.0, apothem])
 
         patches = []
         for i in range(self.number_of_nodes):
@@ -893,7 +920,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         return ax
 
     def set_watershed_boundary_condition_outlet_id(
-        self, outlet_id, node_data, nodata_value=-9999.
+        self, outlet_id, node_data, nodata_value=-9999.0
     ):
         """Set the boundary conditions for a watershed on a HexModelGrid.
 
@@ -961,7 +988,7 @@ class HexModelGrid(VoronoiDelaunayGrid):
         self.status_at_node[outlet_id] = FIXED_VALUE_BOUNDARY
 
     def set_watershed_boundary_condition(
-        self, node_data, nodata_value=-9999., return_outlet_id=False
+        self, node_data, nodata_value=-9999.0, return_outlet_id=False
     ):
         """
         Finds the node adjacent to a boundary node with the smallest value.
@@ -1118,7 +1145,7 @@ def from_dict(param_dict):
     try:
         n_rows = int(param_dict["NUM_ROWS"])
         n_cols = int(param_dict["NUM_COLS"])
-        dx = float(param_dict.get("GRID_SPACING", 1.))
+        dx = float(param_dict.get("GRID_SPACING", 1.0))
     except KeyError:
         raise
     except ValueError:
